@@ -261,10 +261,10 @@ class ClBuilderUpdateAction(Action):
                       'message': __("Calculating dependencies"),
                       'method': 'Builder.emerge_ask('
                                 'update.cl_update_pretend_set,'
-                                '"-uDN","--changed-deps",'
+                                '"-uDN","--rebuilt-binaries",'
                                 '"@world")',
                       'condition': lambda Get:
-                          Get('cl_builder_rebuild_changed_set') == 'on'
+                          Get('cl_builder_rebuilt_binaries_set') == 'on'
                       },
                      {'name': 'update_world',
                       'message': __("Calculating dependencies"),
@@ -272,7 +272,7 @@ class ClBuilderUpdateAction(Action):
                                 'update.cl_update_pretend_set,'
                                 '"-uDN","@world")',
                       'condition': lambda Get:
-                          Get('cl_builder_rebuild_changed_set') != 'on'
+                          Get('cl_builder_rebuilt_binaries_set') != 'on'
                       }
                  ],
                  'condition': lambda Get: (
