@@ -1466,9 +1466,9 @@ class VariableClBuilderPrelinkSet(Variable):
     """
     Выполнять ли prelink
     """
-    type = "bool"
+    type = Variable.Types.Boolean
     opt = ["--prelink"]
-    value = "off"
+    value = Variable.Off
 
     def init(self):
         self.help = _("perform prelink")
@@ -1477,17 +1477,32 @@ class VariableClBuilderPrelinkSet(Variable):
 
 class VariableClBuilderRebuildChangedSet(Variable):
     """
-    Выполнять ли prelink
+    
     """
-    type = "bool"
+    type = Variable.Types.Boolean
     opt = ["--rebuild-changed-packages"]
-    value = "on"
+    value = Variable.On
 
     def init(self):
         self.help = _("rebuild changed packages")
         self.label = _("Rebuild changed packages")
 
 
+class VariableClBuilderRebuiltBinariesSet(Variable):
+    """
+    Выполнить замещение пакетов на бинарную версию если их BUILDTIME
+    меньше, чем в Packages
+    """
+    type = Variable.Types.Boolean
+    opt = ["-B", "--rebuilt-binaries"]
+    value = Variable.Off
+
+    def init(self):
+        self.help = _("replace installed packages with binary packages "
+                      "that have been rebuilt")
+        self.label = _("Rebuild installed packages with binary packages")
+
+
 class VariableClBuilderRescratchSet(ReadonlyVariable):
     """
     Сборка iso образа на самой флешке
